gtoolz.ThreadWithReturn

# ``gtoolz`.`ThreadWithReturn``

class documentation

`class ThreadWithReturn(threading.Thread):`

View In Hierarchy

requires: import threading usage: run_cmd_threaded(cmd) which does this ... dbug("Just getting started...") cmd = "/home/geoffm/ofrd.sh" t1 = ThreadWithReturn(target=run_cmd, args=(cmd,)) t1.start() dbug("Done") result = t1.join() dbug(result)

Method | `__init__` | Undocumented
Method | `join` | Undocumented
Method | `run` | Undocumented
Instance Variable | `_return` | --== SEP_LINE ==--

def __init__(self, *init_args, **init_kwargs):

Undocumented

def join(self):

Undocumented

def run(self):

Undocumented

_return =

--== SEP_LINE ==--